local me = CreateFrame("Frame" );
--- Builds a standard tooltip for a control.
function me:ControlOnEnter()
	GameTooltip:SetOwner(self, "ANCHOR_TOPRIGHT" );
	GameTooltip:SetText(self.tooltipText, nil, nil, nil, nil, 1 );
end

me.okay = function() 
	ElgohSettings["Debug"]=me.Debug:GetChecked();
	ElgohSettings["EPGPValues"]=me.EPGP:GetChecked();
	ElgohSettings["BreaktimeString"]=me.Breaktime:GetText();
	ElgohSettings["MiniLvl"]=tonumber(me.ilvlBox:GetText());
	ElgohSettings["EPGPThreshhold"]=tonumber(me.threshholdBox:GetText());
	ElgohSettings["OSDiscount"]=tonumber(me.discountBox:GetText());
	ElgohSettings["MSString"]=me.Mainspec:GetText();
	ElgohSettings["OSString"]=me.Offspec:GetText();
	for i=1, GuildControlGetNumRanks(), 1 do
		local rank=GuildControlGetRankName(i);
		ElgohRankList[rank]["officer"]=ElgohRankList[rank]["OButton"]:GetChecked();
	end
end

me.cancel = function() 
	me.EPGP:SetChecked(ElgohSettings["EPGPValues"]);
	me.Debug:SetChecked(ElgohSettings["Debug"]);
	me.Breaktime:SetText(ElgohSettings["BreaktimeString"]);
	me.ilvlBox:SetText(ElgohSettings["MiniLvl"]);
	me.threshholdBox:SetText(ElgohSettings["EPGPThreshhold"])
	me.Offspec:SetText(ElgohSettings["OSString"]);
	me.Mainspec:SetText(ElgohSettings["MSString"]);
	me.discountBox:SetText(ElgohSettings["OSDiscount"]);
	for i=1, GuildControlGetNumRanks(), 1 do
		local rank=GuildControlGetRankName(i);
		EDebug(rank);
		if(ElgohRankList[rank]~=nil) then
			ElgohRankList[rank]["OButton"]:SetChecked(ElgohRankList[rank]["officer"])
		end
	end
end

me.default = function() 
	me.EPGP:SetChecked(true);
	me.Debug:SetChecked(false);
	me.Breaktime:SetText("Breaktime! Be back in TIME minutes!");
	me.ilvlBox:SetText("359");
	me.threshholdBox:SetText("750")
	me.discountBox:SetText("0.5");
	me.Offspec:SetText("Roll for ITEM Offspec");
	me.Mainspec:SetText("Roll for ITEM Mainspec");
end

function Elgoh_OptionsLoaded()
	Elgoh_GenerateRankList();
	me.cancel();
end

me.name = "Elgoh";
me:Hide();

-- Pane title
local Title = me:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge" );
Title:SetPoint( "TOPLEFT", 16, -16 );
Title:SetText("Elgoh");
local SubText = me:CreateFontString(nil, "ARTWORK", "GameFontHighlightSmall" );
SubText:SetPoint("TOPLEFT", Title, "BOTTOMLEFT", 0, -8 );
SubText:SetPoint("RIGHT", -32, 0 );
SubText:SetHeight(32);
SubText:SetJustifyH( "LEFT" );
SubText:SetJustifyV( "TOP" );
SubText:SetText("General settings, this part is a work in progress so more settings will be added with each update");

-- Miscellaneous checkboxes
me.Debug = CreateFrame("CheckButton", "ElgohDebugCheckbox", me, "InterfaceOptionsCheckButtonTemplate");
me.Debug:SetPoint( "TOPLEFT", SubText, "BOTTOMLEFT", -2, -8 );
getglobal(me.Debug:GetName() .. "Text"):SetText("Enable Debug Mode");
me.Debug.tooltipText = "Enables Debug Mode";

me.EPGP = CreateFrame("CheckButton", "ElgohEPGPCheckbox", me, "InterfaceOptionsCheckButtonTemplate");
me.EPGP:SetPoint( "TOPLEFT", me.Debug, "BOTTOMLEFT", -0, -8 );
getglobal(me.EPGP:GetName() .. "Text"):SetText("Toggle EPGP Values");
me.EPGP.tooltipText = "Toggles showing of EPGP values in item tooltips";

-- Breaktime
local BreakLabel = me:CreateFontString( nil, "ARTWORK", "GameFontHighlight" );
BreakLabel:SetPoint( "TOPLEFT", me.EPGP, "BOTTOMLEFT", -0, -10 );
BreakLabel:SetText("Text to post during /breaktime");

me.Breaktime = CreateFrame("EditBox", "ElgohBreaktimeBox", me, "InputBoxTemplate")
me.Breaktime:SetWidth(400)
me.Breaktime:SetHeight(20)
me.Breaktime:SetPoint("TOP", BreakLabel, "TOP", 0,2);
me.Breaktime:SetPoint("LEFT", BreakLabel, "RIGHT", 15,0);
me.Breaktime:SetAutoFocus(false)
me.Breaktime:SetScript("OnEnterPressed", function() me.Breaktime:ClearFocus(); end)
me.Breaktime.tooltipText="\"TIME\" will be replaced with the time in minutes";
me.Breaktime:SetScript( "OnEnter", me.ControlOnEnter);
me.Breaktime:SetScript( "OnLeave", GameTooltip_Hide);

-- Mainspec
local MainspecLabel = me:CreateFontString( nil, "ARTWORK", "GameFontHighlight" );
MainspecLabel:SetPoint( "TOPLEFT", BreakLabel, "BOTTOMLEFT", -0, -30 );
MainspecLabel:SetText("What to post for Mainspec Rolls");

me.Mainspec = CreateFrame("EditBox", "ElgohMainspecBox", me, "InputBoxTemplate")
me.Mainspec:SetWidth(400)
me.Mainspec:SetHeight(20)
me.Mainspec:SetPoint("TOP", MainspecLabel, "TOP", 0,2);
me.Mainspec:SetPoint("LEFT", me.Breaktime, "LEFT", 0,0);
me.Mainspec:SetAutoFocus(false)
me.Mainspec:SetScript("OnEnterPressed", function() me.Mainspec:ClearFocus(); end)
me.Mainspec.tooltipText="\"ITEM\" will be replace with the item link";
me.Mainspec:SetScript( "OnEnter", me.ControlOnEnter);
me.Mainspec:SetScript( "OnLeave", GameTooltip_Hide);

-- Offspec
local OffspecLabel = me:CreateFontString( nil, "ARTWORK", "GameFontHighlight" );
OffspecLabel:SetPoint( "TOPLEFT", MainspecLabel, "BOTTOMLEFT", -0, -10 );
OffspecLabel:SetText("What to post for Offspec Rolls");

me.Offspec = CreateFrame("EditBox", "ElgohOffspecBox", me, "InputBoxTemplate")
me.Offspec:SetWidth(400)
me.Offspec:SetHeight(20)
me.Offspec:SetPoint("TOP", OffspecLabel, "TOP", 0,2);
me.Offspec:SetPoint("LEFT", me.Breaktime, "LEFT", 0,0);
me.Offspec:SetAutoFocus(false)
me.Offspec:SetScript("OnEnterPressed", function() me.Offspec:ClearFocus(); end)
me.Offspec.tooltipText="\"ITEM\" will be replace with the item link";
me.Offspec:SetScript( "OnEnter", me.ControlOnEnter);
me.Offspec:SetScript( "OnLeave", GameTooltip_Hide);

--ItemLevel
me.ilvlBox = CreateFrame("EditBox", "ElgohilvlBox", me, "InputBoxTemplate")
me.ilvlBox:SetWidth(60)
me.ilvlBox:SetHeight(20)
me.ilvlBox:SetPoint("TOP", me.EPGP, "TOP", 0,0);
me.ilvlBox:SetPoint("LEFT", me.Breaktime, "LEFT", 0,0);
me.ilvlBox:SetAutoFocus(false)
me.ilvlBox:SetJustifyH("CENTER");
me.ilvlBox:SetScript("OnEnterPressed", function() me.ilvlBox:ClearFocus(); end)
me.ilvlBox.tooltipText="The minimum Item Level of gear to display EPGP values for";
me.ilvlBox:SetScript( "OnEnter", me.ControlOnEnter );
me.ilvlBox:SetScript( "OnLeave", GameTooltip_Hide );

--Threshhold
me.threshholdBox = CreateFrame("EditBox", "ElgohThreshholdBox", me, "InputBoxTemplate")
me.threshholdBox:SetWidth(60)
me.threshholdBox:SetHeight(20)
me.threshholdBox:SetPoint("TOP", me.ilvlBox, "TOP", 0,0);
me.threshholdBox:SetPoint("LEFT", me.ilvlBox, "RIGHT", 30,0);
me.threshholdBox:SetAutoFocus(false)
me.threshholdBox:SetJustifyH("CENTER");
me.threshholdBox:SetScript("OnEnterPressed", function() me.threshholdBox:ClearFocus(); end)
me.threshholdBox.tooltipText="The EPGP Threshhold. This only matters if you are the Master Looter";
me.threshholdBox:SetScript( "OnEnter", me.ControlOnEnter );
me.threshholdBox:SetScript( "OnLeave", GameTooltip_Hide );

--Discount
me.discountBox = CreateFrame("EditBox", "ElgohDiscountBox", me, "InputBoxTemplate")
me.discountBox:SetWidth(60)
me.discountBox:SetHeight(20)
me.discountBox:SetPoint("TOP", me.ilvlBox, "TOP", 0,0);
me.discountBox:SetPoint("LEFT", me.threshholdBox, "RIGHT", 30,0);
me.discountBox:SetAutoFocus(false)
me.discountBox:SetJustifyH("CENTER");
me.discountBox:SetScript("OnEnterPressed", function() me.discountBox:ClearFocus(); end)
me.discountBox.tooltipText="The EPGP discount for Off-SPec gear. OriginalPrice x Discount, set to 1 for no discount";
me.discountBox:SetScript( "OnEnter", me.ControlOnEnter );
me.discountBox:SetScript( "OnLeave", GameTooltip_Hide );

--Misc Tooltips
-- edtPTarget.tooltipText="Type text here then press enter to have your current target say it in guild/party/raid (requires elgoh)";
-- edtPTarget:SetScript("OnEnter", me.ControlOnEnter); 
-- edtPTarget:SetScript("OnLeave", GameTooltip_Hide);

function EDB_MakeTooltips()
	EDBMSButton.tooltipText="Click to cycle the Main Spec";
	EDBMSButton:SetScript( "OnEnter", me.ControlOnEnter );
	EDBMSButton:SetScript( "OnLeave", GameTooltip_Hide );
	EDBOSButton.tooltipText="Click to cycle the Off-Spec";
	EDBOSButton:SetScript( "OnEnter", me.ControlOnEnter );
	EDBOSButton:SetScript( "OnLeave", GameTooltip_Hide );
end

--RANKS
function Elgoh_GenerateRankList()
if(oldRankList~=nil) then return; end
	oldRankList = ElgohRankList;
	ElgohRankList={};
	
	local OfficerLabel = me:CreateFontString( nil, "ARTWORK", "GameFontHighlight" );
	OfficerLabel:SetPoint( "TOPLEFT", OffspecLabel, "TOPLEFT", -0, -20 );
	OfficerLabel:SetText("Auto Promote:");

	for i=1, GuildControlGetNumRanks(), 1 do
		local rank=GuildControlGetRankName(i);
		if ElgohRankList[rank]==nil then 
			ElgohRankList[rank]={};
			ElgohRankList[rank]["label"] = me:CreateFontString( nil, "ARTWORK", "GameFontHighlight" );
			ElgohRankList[rank]["label"]:SetPoint( "TOPLEFT", OffspecLabel, "TOPLEFT", -0, -(30+(i*20)) );
			ElgohRankList[rank]["label"]:SetText(rank);
	
			ElgohRankList[rank]["OButton"] = CreateFrame("CheckButton", nil, me, "InterfaceOptionsCheckButtonTemplate");
			ElgohRankList[rank]["OButton"]:SetPoint("BOTTOM", ElgohRankList[rank]["label"], "BOTTOM", 0, -10 );
			ElgohRankList[rank]["OButton"]:SetPoint("LEFT", me, "LEFT", 230, 0 );
			ElgohRankList[rank]["OButton"].tooltipText="This rank will be automatically promoted in raids (/lgoh auto)";
			ElgohRankList[rank]["OButton"]:SetScript( "OnEnter", me.ControlOnEnter);
			ElgohRankList[rank]["OButton"]:SetScript( "OnLeave", GameTooltip_Hide);
			if(oldRankList[rank]~=nil) then
				ElgohRankList[rank]["officer"]=oldRankList[rank]["officer"];
			end
		end
	end
end

me:SetScript("OnShow", Elgoh_OptionsLoaded);
InterfaceOptions_AddCategory(me);

		
-- Elgoh.childpanel = CreateFrame( "Frame", "ElgohChild", Elgoh.panel);
-- Elgoh.childpanel.name = "MyChild";
-- Elgoh.childpanel.parent = Elgoh.panel.name;
-- InterfaceOptions_AddCategory(Elgoh.childpanel)